@@ -7,7 +7,7 @@ from re import S
 #         '':'߽ Ͷ.+(?=ڰ˽)','':'(?<=)ʮһ˽ļͶ.+(?<!)(?=ʮ)','̩':'ʮһ˽ļͶ[\S\s\n]+(?<!)(?=ʮ)','㷢':'ʮһ Ͷ.+(?<!)(?=ʮ)'}
 
 def get_chapter_regex(tg, beg_chapter_name, end_chapter_name):
-        if tg=='̩' or tg=='' or tg=='' or tg=='' or tg=='' or tg=='ƽ' or tg=='' or tg=='㷢' or tg=='Ͷ' or tg=='': #done
+        if tg=='̩' or tg=='' or tg=='' or tg=='' or tg=='ƽ' or tg=='' or tg=='㷢' or tg=='Ͷ' or tg=='' or tg=='': #done
                 return r'(?<='+beg_chapter_name+r'[\S\s\n\t]+)'+beg_chapter_name+r'[\S\s\n\t]{10,}?(?='+end_chapter_name+')'
         if tg=='': #done
                 return r'(?<=--	'+beg_chapter_name+')'+r'[\S\s\n\t]{10,}?(?=--	'+end_chapter_name+')'
@@ -26,7 +26,7 @@ def get_section_regex(tg, beg_section_name, end_section_name):
         if tg=='ͨ': #done
                 return r'(?<=--		'+beg_section_name+r')[\S\s\n\t]+?(?=--		'+end_section_name+')'
         if tg=='ҵ': #done
-                return r'(?<=--(\t|	)'+beg_section_name+r')[\S\s\n\t]+?(?=--(\t|	)'+end_section_name+')'
+                return r'(?<=--(\t| )'+beg_section_name+r')[\S\s\n\t]+?(?=--(\t|	)'+end_section_name+')'
 
 def get_section_beg_end(tg, req_section):
         sections_dict = {'̩':['ͶĿ','ͶʷΧ','Ͷʲ','ҵȽϻ׼','Ͷ','ͶʽֹΪ'],
@@ -34,7 +34,8 @@ def get_section_beg_end(tg, req_section):
                          '':['ͶĿ','ͶʷΧ','Ͷ','׾Լ¶','ȫݶڴȨͬ','Ԥֹ','˽ļзشʩ','𱸰ǰֽ','ȯ','Ͷʾ'],
                          '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','Ͷʾָ','ҵȽϻ׼','տ','ڴ͸ԭԼ','ͶʽֹΪ','ʹƲͶ֤ȯȨԭ򼰷','',''],
                          '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','Ͷʾָͱ','տ','׼ͻ',''],
-                         '':['ͶĿ','ͶʷΧ','ͶʷΧı','Ͷʲ','Ͷ','ֹΪ','ͻ','ȫݶڴȨͬ⣺','Ԥƽֻ','ʡȯ֤ȯҵ','йͶʼලΧ'],
+                         '1':['ͶĿ','ͶʷΧ','ͶʷΧı','Ͷʲ','Ͷ','ֹΪ','ͻ','ȫݶڴȨͬ⣺','Ԥƽֻ','ʡȯ֤ȯҵ','йͶʼලΧ'],
+                         '2':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ֹΪ','ͻ','ҵȽϻ׼','','Ԥƽֻ','ʡȯ֤ȯҵУ','ͱʮڡͶʡԼݣ'],
                          '㷢':['Ʋı봦','Ʋ˻Ŀ͹', 'ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׼ͻμʽ','','Ԥֹ','ҵȽϻ׼','йͶʼලԼ'],
                          'ͨ':['Ͷʾ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׵μʽ','','ҵȽϻ׼','ȯҵ֤ȯҵ','Ԥֹ'],
                          'ƽ':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','/','ͶʽֹΪ','Ԥֹտ','ҵȽϻ׼У','','Ͷߵı'],
